Get in touch
============

If you would like to start a discussion with the wider GLASS community about
e.g. a design decision or API change, you can use our Discussions__ page.

__ https://github.com/orgs/glass-dev/discussions

We also have a public `Slack workspace`__ for discussions about the project.

__ https://glass-dev.github.io/slack
